....
....

#define APP_TIMER_PRESCALER             0                                          /**< Value of the RTC1 PRESCALER register. */
#define APP_TIMER_OP_QUEUE_SIZE         4                                          /**< Size of timer operation queues. */
#define BATTERY_LEVEL_MEAS_INTERVAL     APP_TIMER_TICKS(2000, APP_TIMER_PRESCALER) /**< Battery level measurement interval (ticks). */
#define TEMPERATURE_MEAS_INTERVAL       APP_TIMER_TICKS(1000, APP_TIMER_PRESCALER)

#define MIN_CONN_INTERVAL               MSEC_TO_UNITS(500, UNIT_1_25_MS)           /**< Minimum acceptable connection interval (0.5 seconds) */
#define MAX_CONN_INTERVAL               MSEC_TO_UNITS(1000, UNIT_1_25_MS)          /**< Maximum acceptable connection interval (1 second). */
#define SLAVE_LATENCY                   0                                          /**< Slave latency. */
#define CONN_SUP_TIMEOUT                MSEC_TO_UNITS(4000, UNIT_10_MS)            /**< Connection supervisory timeout (4 seconds). */

#define FIRST_CONN_PARAMS_UPDATE_DELAY  APP_TIMER_TICKS(5000, APP_TIMER_PRESCALER) /**< Time from initiating event (connect or start of indication) to first time sd_ble_gap_conn_param_update is called (5 seconds). */
#define NEXT_CONN_PARAMS_UPDATE_DELAY   APP_TIMER_TICKS(30000, APP_TIMER_PRESCALER)/**< Time between each call to sd_ble_gap_conn_param_update after the first call (30 seconds). */
#define MAX_CONN_PARAMS_UPDATE_COUNT    3                                          /**< Number of attempts before giving up the connection parameter negotiation. */

....

APP_TIMER_DEF(m_battery_timer_id);                                                 /**< Battery timer. */
APP_TIMER_DEF(m_temp_timer_id);  


/*******************************************
* 			Function implementing	 	   *
/*******************************************/

uint32_t ble_ess_temperature_send(ble_ess_t * p_ess, int temp)
{
    uint32_t err_code;	
    // Send value if connected
    if (p_ess->conn_handle != BLE_CONN_HANDLE_INVALID)
    {
        uint8_t                encoded_temp_meas[UINT16_LEN];
        uint16_t               len = 0;
       	ble_gatts_value_t 	   gatts_value;
		
		encoded_temp_meas[len++] = (uint8_t) ((temp & 0x00FF) >> 0);
    	encoded_temp_meas[len++] = (uint8_t) ((temp & 0xFF00) >> 8);
		
		gatts_value.len     = len;
        gatts_value.offset  = 0;
        gatts_value.p_value = encoded_temp_meas;
		
	    err_code = sd_ble_gatts_value_set(p_ess->conn_handle,
                                          p_ess->temp_handles.ess_char_handle.value_handle,
                                          &gatts_value);

        if (err_code != NRF_SUCCESS)
        {
            return err_code;
        }

		if (p_ess->temp_is_supported.support_notification)
		{
			ble_gatts_hvx_params_t hvx_params;
	        memset(&hvx_params, 0, sizeof(hvx_params));
			
	        hvx_params.handle = p_ess->temp_handles.ess_char_handle.value_handle;
	        hvx_params.type   = BLE_GATT_HVX_NOTIFICATION;
	        hvx_params.offset = gatts_value.offset;
	        hvx_params.p_len  = &gatts_value.len;
	        hvx_params.p_data = gatts_value.p_value;
		
	        err_code = sd_ble_gatts_hvx(p_ess->conn_handle, &hvx_params);
		}	
    }
    else
    {
        err_code = NRF_ERROR_INVALID_STATE;
    }

    return err_code;
}

/* sending one Temperature Measurement. */
static void temperature_measurement_send(void)
{
    int 		   temp_data;
    uint32_t       err_code;
	
	float temper = TH02_ReadTemperature();
	uint32_t new_temperature = transform_data(temper);
	if (temperature_data == new_temperature) return;
	temperature_data = new_temperature;
	
	temp_data = (int) ((temperature_data & 0x0000FFFF));
	
    err_code = ble_ess_temperature_send(&m_ess, temp_data);

    if ((err_code != NRF_SUCCESS) &&
        (err_code != NRF_ERROR_INVALID_STATE) &&
        (err_code != BLE_ERROR_NO_TX_PACKETS) &&
        (err_code != BLE_ERROR_GATTS_SYS_ATTR_MISSING)
        )
    {
        APP_ERROR_HANDLER(err_code);
    }
}

/* temperature and humidity timer timeout handler */
static void environmental_sensing_timeout_handler(void * p_context)
{
    UNUSED_PARAMETER(p_context);		
 	if (m_conn_handle != BLE_CONN_HANDLE_INVALID)
    {
    	temperature_measurement_send();
		humidity_measurement_send();
    }
}

/* setting timer */
static void timers_init(void)
{
    uint32_t err_code;

    // Initialize timer module.
    APP_TIMER_INIT(APP_TIMER_PRESCALER, APP_TIMER_OP_QUEUE_SIZE, false);

    // Create timers.
    err_code = app_timer_create(&m_battery_timer_id,
                                APP_TIMER_MODE_REPEATED,
                                battery_level_meas_timeout_handler);
    APP_ERROR_CHECK(err_code);
	
	err_code = app_timer_create(&m_temp_timer_id,
                                APP_TIMER_MODE_REPEATED,
                                environmental_sensing_timeout_handler);
    APP_ERROR_CHECK(err_code);
}


/* start timer */
static void application_timers_start(void)
{
    uint32_t err_code;

    // Start application timers.
    err_code = app_timer_start(m_battery_timer_id, BATTERY_LEVEL_MEAS_INTERVAL, NULL);
	APP_ERROR_CHECK(err_code);
		
	err_code = app_timer_start(m_temp_timer_id, TEMPERATURE_MEAS_INTERVAL, NULL);
	APP_ERROR_CHECK(err_code);
}

int main(void)
{
    uint32_t err_code;
    bool erase_bonds;

    // Initialize.
    ...
	...
	
    timers_init();
    ...
	...
	
    // Start execution.
    application_timers_start();
    err_code = ble_advertising_start(BLE_ADV_MODE_FAST);
    APP_ERROR_CHECK(err_code);

    // Enter main loop.
    for (;; )
    {
        power_manage();
    }
}